@@ -15,3 +15,7 @@ mv nheko.dmg ..
 popd
 
 dmgbuild -s ./.ci/macos/settings.json "Nheko" nheko.dmg
+
+if [ ! -z $TRAVIS_TAG ]; then
+    mv nheko.dmg nheko-${TRAVIS_TAG}.dmg
+fi
